@@ -147,8 +147,8 @@ void PointerInputTest::initTestCase()
     QSignalSpy workspaceCreatedSpy(kwinApp(), &Application::workspaceCreated);
     QVERIFY(workspaceCreatedSpy.isValid());
     kwinApp()->platform()->setInitialWindowSize(QSize(1280, 1024));
-    QMetaObject::invokeMethod(kwinApp()->platform(), "setVirtualOutputs", Qt::DirectConnection, Q_ARG(int, 2));
     QVERIFY(waylandServer()->init(s_socketName.toLocal8Bit()));
+    QMetaObject::invokeMethod(kwinApp()->platform(), "setVirtualOutputs", Qt::DirectConnection, Q_ARG(int, 2));
 
     kwinApp()->setConfig(KSharedConfig::openConfig(QString(), KConfig::SimpleConfig));
 
@@ -365,8 +365,7 @@ void PointerInputTest::testUpdateFocusAfterScreenChange()
     QVERIFY(window->geometry().contains(Cursor::pos()));
 
     // and we should get an enter event
-    QVERIFY(enteredSpy.wait());
-    QCOMPARE(enteredSpy.count(), 1);
+    QTRY_COMPARE(enteredSpy.count(), 1);
 }
 
 void PointerInputTest::testModifierClickUnrestrictedMove_data()
@@ -1079,7 +1078,7 @@ class HelperEffect : public Effect
     Q_OBJECT
 public:
     HelperEffect() {}
-    ~HelperEffect() {}
+    ~HelperEffect() override {}
 };
 
 void PointerInputTest::testEffectOverrideCursorImage()
