@@ -25,6 +25,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QDesktopWidget>
 #include <QQmlEngine>
 #include <QQmlContext>
+#include <QScreen>
 #include <QStandardPaths>
 #include <KConfigGroup>
 #include <KDesktopFile>
@@ -116,13 +117,6 @@ bool LayoutPreview::eventFilter(QObject *object, QEvent *event)
 ExampleClientModel::ExampleClientModel (QObject* parent)
     : QAbstractListModel (parent)
 {
-    QHash<int, QByteArray> roles;
-    roles[Qt::UserRole] = "caption";
-    roles[Qt::UserRole+1] = "minimized";
-    roles[Qt::UserRole + 3] = "icon";
-    roles[Qt::UserRole+2] = "desktopName";
-    roles[Qt::UserRole+4] = "windowId";
-    setRoleNames(roles);
     init();
 }
 
@@ -199,6 +193,18 @@ int ExampleClientModel::rowCount(const QModelIndex &parent) const
     return m_services.size();
 }
 
+QHash<int, QByteArray> ExampleClientModel::roleNames() const
+{
+    // FIXME: Use an enum.
+    return {
+        { Qt::UserRole, QByteArrayLiteral("caption") },
+        { Qt::UserRole + 1, QByteArrayLiteral("minimized") },
+        { Qt::UserRole + 2, QByteArrayLiteral("desktopName") },
+        { Qt::UserRole + 3, QByteArrayLiteral("icon") },
+        { Qt::UserRole + 4, QByteArrayLiteral("windowId") },
+    };
+}
+
 SwitcherItem::SwitcherItem(QObject *parent)
     : QObject(parent)
     , m_model(new ExampleClientModel(this))
@@ -238,7 +244,8 @@ void SwitcherItem::setCurrentIndex(int index)
 
 QRect SwitcherItem::screenGeometry() const
 {
-    return qApp->desktop()->screenGeometry(qApp->desktop()->primaryScreen());
+    const QScreen *primaryScreen = qApp->primaryScreen();
+    return primaryScreen->geometry();
 }
 
 void SwitcherItem::incrementIndex()
