@@ -121,8 +121,8 @@ ApplicationWayland::~ApplicationWayland()
         return;
     }
 
-    if (kwinApp()->platform()) {
-        kwinApp()->platform()->setOutputsEnabled(false);
+    if (auto *platform = kwinApp()->platform()) {
+        platform->prepareShutdown();
     }
     // need to unload all effects prior to destroying X connection as they might do X calls
     if (effects) {
@@ -180,7 +180,7 @@ void ApplicationWayland::continueStartupWithScreens()
 {
     disconnect(kwinApp()->platform(), &Platform::screensQueried, this, &ApplicationWayland::continueStartupWithScreens);
     createScreens();
-    createCompositor();
+    WaylandCompositor::create();
     connect(Compositor::self(), &Compositor::sceneCreated, this, &ApplicationWayland::continueStartupWithScene);
 }
 
@@ -247,7 +247,19 @@ void ApplicationWayland::startSession()
         p->setProcessChannelMode(QProcess::ForwardedErrorChannel);
         p->setProcessEnvironment(processStartupEnvironment());
         auto finishedSignal = static_cast<void (QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished);
-        connect(p, finishedSignal, this, &ApplicationWayland::quit);
+        connect(p, finishedSignal, this, [](int code, QProcess::ExitStatus status) {
+            if (status == QProcess::CrashExit) {
+                qWarning() << "Session process has crashed";
+                QCoreApplication::exit(-1);
+                return;
+            }
+
+            if (code) {
+                qWarning() << "Session process exited with code" << code;
+            }
+
+            QCoreApplication::exit(code);
+        });
         p->start(m_sessionArgument);
     }
     // start the applications passed to us as command line arguments
@@ -300,7 +312,8 @@ static void disablePtrace()
     const QFileInfo parent(QStringLiteral("/proc/%1/exe").arg(getppid()));
     if (parent.isSymLink() &&
             (parent.symLinkTarget().endsWith(QLatin1String("/gdb")) ||
-             parent.symLinkTarget().endsWith(QLatin1String("/gdbserver")))) {
+             parent.symLinkTarget().endsWith(QLatin1String("/gdbserver")) ||
+             parent.symLinkTarget().endsWith(QLatin1String("/lldb-server")))) {
         // debugger, don't adjust
         return;
     }
