@@ -4,6 +4,7 @@
 
 Copyright (C) 2013, 2016 Martin Gräßlin <mgraesslin@kde.org>
 Copyright (C) 2018 Roman Gilg <subdiff@gmail.com>
+Copyright (C) 2019 Vlad Zagorodniy <vladzzag@gmail.com>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -61,9 +62,9 @@ class KWIN_EXPORT PointerInputRedirection : public InputDeviceHandler
     Q_OBJECT
 public:
     explicit PointerInputRedirection(InputRedirection *parent);
-    virtual ~PointerInputRedirection();
+    ~PointerInputRedirection() override;
 
-    void init();
+    void init() override;
 
     void updateAfterScreenChange();
     bool supportsWarping() const;
@@ -97,51 +98,51 @@ public:
 
     /**
      * @internal
-     **/
+     */
     void processMotion(const QPointF &pos, uint32_t time, LibInput::Device *device = nullptr);
     /**
      * @internal
-     **/
+     */
     void processMotion(const QPointF &pos, const QSizeF &delta, const QSizeF &deltaNonAccelerated, uint32_t time, quint64 timeUsec, LibInput::Device *device);
     /**
      * @internal
-     **/
+     */
     void processButton(uint32_t button, InputRedirection::PointerButtonState state, uint32_t time, LibInput::Device *device = nullptr);
     /**
      * @internal
-     **/
-    void processAxis(InputRedirection::PointerAxis axis, qreal delta, uint32_t time, LibInput::Device *device = nullptr);
+     */
+    void processAxis(InputRedirection::PointerAxis axis, qreal delta, qint32 discreteDelta, InputRedirection::PointerAxisSource source, uint32_t time, LibInput::Device *device = nullptr);
     /**
      * @internal
-     **/
+     */
     void processSwipeGestureBegin(int fingerCount, quint32 time, KWin::LibInput::Device *device = nullptr);
     /**
      * @internal
-     **/
+     */
     void processSwipeGestureUpdate(const QSizeF &delta, quint32 time, KWin::LibInput::Device *device = nullptr);
     /**
      * @internal
-     **/
+     */
     void processSwipeGestureEnd(quint32 time, KWin::LibInput::Device *device = nullptr);
     /**
      * @internal
-     **/
+     */
     void processSwipeGestureCancelled(quint32 time, KWin::LibInput::Device *device = nullptr);
     /**
      * @internal
-     **/
+     */
     void processPinchGestureBegin(int fingerCount, quint32 time, KWin::LibInput::Device *device = nullptr);
     /**
      * @internal
-     **/
+     */
     void processPinchGestureUpdate(qreal scale, qreal angleDelta, const QSizeF &delta, quint32 time, KWin::LibInput::Device *device = nullptr);
     /**
      * @internal
-     **/
+     */
     void processPinchGestureEnd(quint32 time, KWin::LibInput::Device *device = nullptr);
     /**
      * @internal
-     **/
+     */
     void processPinchGestureCancelled(quint32 time, KWin::LibInput::Device *device = nullptr);
 
 private:
@@ -184,7 +185,7 @@ class CursorImage : public QObject
     Q_OBJECT
 public:
     explicit CursorImage(PointerInputRedirection *parent = nullptr);
-    virtual ~CursorImage();
+    ~CursorImage() override;
 
     void setEffectsOverrideCursor(Qt::CursorShape shape);
     void removeEffectsOverrideCursor();
