@@ -66,9 +66,7 @@ struct SessionInfo {
     bool active; // means 'was active in the saved session'
     int stackingOrder;
     float opacity;
-    int tabGroup; // Unique identifier for the client group that this window is in
 
-    Client* tabGroupClient; // The first client created that has an identical identifier
     QStringList activities;
 };
 
@@ -85,7 +83,7 @@ class KWIN_EXPORT SessionSaveDoneHelper
     Q_OBJECT
 public:
     SessionSaveDoneHelper();
-    virtual ~SessionSaveDoneHelper();
+    ~SessionSaveDoneHelper() override;
     SmcConn connection() const {
         return conn;
     }
