@@ -26,9 +26,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QModelIndex>
 #include <QPixmap>
 #include <QString>
-#include <X11/Xlib.h>
-#include <fixx11h.h>
-#include <xcb/xcb.h>
 
 /**
  * @file
@@ -38,7 +35,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  * @author Martin Gräßlin <mgraesslin@kde.org>
  * @since 4.4
- **/
+ */
 
 class QKeyEvent;
 
@@ -74,7 +71,7 @@ namespace KWin
  * itself is made up of two widgets: one to show the complete list and one to show only the selected
  * item. This way it is possible to have a view which shows for example a list containing only small
  * icons and nevertheless show the title of the currently selected client.
- **/
+ */
 namespace TabBox
 {
 class DesktopModel;
@@ -90,27 +87,27 @@ typedef QList< QWeakPointer< TabBoxClient > > TabBoxClientList;
  *
  * @author Martin Gräßlin <mgraesslin@kde.org>
  * @since 4.4
- **/
+ */
 class TabBoxHandler : public QObject
 {
     Q_OBJECT
 public:
     TabBoxHandler(QObject *parent);
-    virtual ~TabBoxHandler();
+    ~TabBoxHandler() override;
 
     /**
      * @return The id of the active screen
-     **/
+     */
     virtual int activeScreen() const = 0;
     /**
      * @return The current active TabBoxClient or NULL
      * if there is no active client.
-     **/
+     */
     virtual QWeakPointer<TabBoxClient> activeClient() const = 0;
     /**
      * @param client The client which is starting point to find the next client
      * @return The next TabBoxClient in focus chain
-     **/
+     */
     virtual QWeakPointer<TabBoxClient> nextClientFocusChain(TabBoxClient* client) const = 0;
     /**
      * This method is used by the ClientModel to find an entrance into the focus chain in case
@@ -118,7 +115,7 @@ public:
      *
      * @return The first Client of the focus chain
      * @since 4.9.1
-     **/
+     */
     virtual QWeakPointer<TabBoxClient> firstClientFocusChain() const = 0;
     /**
      * Checks whether the given @p client is part of the focus chain at all.
@@ -132,66 +129,66 @@ public:
      * @param client The Client to check whether it is in the Focus Chain
      * @return @c true in case the Client is part of the focus chain, @c false otherwise.
      * @since 4.9.2
-     **/
+     */
     virtual bool isInFocusChain(TabBoxClient* client) const = 0;
     /**
      * @param client The client whose desktop name should be retrieved
      * @return The desktop name of the given TabBoxClient. If the client is
      * on all desktops the name of current desktop will be returned.
-     **/
+     */
     virtual QString desktopName(TabBoxClient* client) const = 0;
     /**
      * @param desktop The desktop whose name should be retrieved
      * @return The desktop name of given desktop
-     **/
+     */
     virtual QString desktopName(int desktop) const = 0;
     /**
      * @return The number of current desktop
-     **/
+     */
     virtual int currentDesktop() const = 0;
     /**
      * @return The number of virtual desktops
-     **/
+     */
     virtual int numberOfDesktops() const = 0;
     /**
      * @param desktop The desktop which is the starting point to find the next desktop
      * @return The next desktop in the current focus chain.
-     **/
+     */
     virtual int nextDesktopFocusChain(int desktop) const = 0;
 
     /**
      * whether KWin is currently compositing and it's related features (elevating) can be used
-     **/
+     */
     virtual bool isKWinCompositing() const = 0;
 
     /**
      * De-/Elevate a client using the compositor (if enabled)
-     **/
+     */
     virtual void elevateClient(TabBoxClient* c, QWindow *tabbox, bool elevate) const = 0;
 
     /**
      * Raise a client (w/o activating it)
-     **/
+     */
     virtual void raiseClient(TabBoxClient* c) const = 0;
 
     /**
      * @param c The client to be restacked
      * @param under The client the other one will be placed below
-     **/
+     */
     virtual void restack(TabBoxClient *c, TabBoxClient *under) = 0;
 
     /**
      * Toggle between ShadeHover and ShadeNormal - not shaded windows are unaffected
      * @param c The client to be shaded
      * @param b Whether to un- or shade
-     **/
+     */
     virtual void shadeClient(TabBoxClient *c, bool b) const = 0;
 
     virtual void highlightWindows(TabBoxClient *window = nullptr, QWindow *controller = nullptr) = 0;
 
     /**
      * @return The current stacking order of TabBoxClients
-     **/
+     */
     virtual TabBoxClientList stackingOrder() const = 0;
     /**
      * Determines if given client will be added to the list:
@@ -208,26 +205,26 @@ public:
      * @param desktop The desktop the client should be on. This is irrelevant if allDesktops is set
      * @param allDesktops Add clients from all desktops or only from current
      * @return The client to be included in the list or NULL if it isn't to be included
-     **/
+     */
     virtual QWeakPointer<TabBoxClient> clientToAddToList(TabBoxClient* client, int desktop) const = 0;
     /**
      * @return The first desktop window in the stacking order.
-     **/
+     */
     virtual QWeakPointer<TabBoxClient> desktopClient() const = 0;
     /**
      * Activates the currently selected client and closes the TabBox.
-     **/
+     */
     virtual void activateAndClose() = 0;
 
     /**
      * @return The currently used TabBoxConfig
-     **/
+     */
     const TabBoxConfig& config() const;
     /**
      * Call this method when you want to change the currently used TabBoxConfig.
      * It fires the signal configChanged.
      * @param config Updates the currently used TabBoxConfig to config
-     **/
+     */
     void setConfig(const TabBoxConfig& config);
 
     /**
@@ -238,24 +235,24 @@ public:
      * TabBoxConfig::TabBoxMode is TabBoxConfig::DesktopTabBox.
      * @see TabBoxConfig::isShowTabBox
      * @see TabBoxConfig::isHighlightWindows
-     **/
+     */
     void show();
     /**
      * Hides the TabBoxView if shown.
      * Deactivates highlight windows effect if active.
      * @see show
-     **/
+     */
     void hide(bool abort = false);
 
     /**
      * Sets the current model index in the view and updates
      * highlight windows if active.
      * @param index The current Model index
-     **/
+     */
     void setCurrentIndex(const QModelIndex& index);
     /**
      * @returns the current index
-     **/
+     */
     const QModelIndex &currentIndex() const;
 
     /**
@@ -263,7 +260,7 @@ public:
      * @param forward next or previous item
      * @return The next or previous item. If there is no matching item
      * the current item will be returned.
-     **/
+     */
     QModelIndex nextPrev(bool forward) const;
 
     /**
@@ -273,65 +270,65 @@ public:
      * In that case partialReset has to be true.
      *
      * @param partialReset Keep the currently selected item or regenerate everything
-     **/
+     */
     void createModel(bool partialReset = false);
 
     /**
      * @param desktop The desktop whose index should be retrieved
      * @return The model index of given desktop. If TabBoxMode is not
      * TabBoxConfig::DesktopTabBox an invalid model index will be returned.
-     **/
+     */
     QModelIndex desktopIndex(int desktop) const;
     /**
      * @return The current list of desktops.
      * If TabBoxMode is not TabBoxConfig::DesktopTabBox an empty list will
      * be returned.
      * @see DesktopModel::desktopList
-     **/
+     */
     QList< int > desktopList() const;
     /**
      * @return The desktop for given model index. If the index is not valid
      * or TabBoxMode is not TabBoxConfig::DesktopTabBox -1 will be returned.
      * @see DesktopModel::desktopIndex
-     **/
+     */
     int desktop(const QModelIndex& index) const;
 
     /**
      * Handles additional grabbed key events by the TabBox controller.
      * @param event The key event which has been grabbed
-     **/
+     */
     virtual void grabbedKeyEvent(QKeyEvent* event) const;
     /**
      * @param pos The position to be tested in global coordinates
      * @return True if the view contains the point, otherwise false.
-     **/
+     */
     bool containsPos(const QPoint& pos) const;
     /**
      * @param client The TabBoxClient whose index should be returned
      * @return Returns the ModelIndex of given TabBoxClient or an invalid ModelIndex
      * if the model does not contain the given TabBoxClient.
      * @see ClientModel::index
-     **/
+     */
     QModelIndex index(QWeakPointer<TabBoxClient> client) const;
     /**
      * @return Returns the current list of TabBoxClients.
      * If TabBoxMode is not TabBoxConfig::ClientTabBox an empty list will
      * be returned.
      * @see ClientModel::clientList
-     **/
+     */
     TabBoxClientList clientList() const;
     /**
      * @param index The index of the client to be returned
      * @return Returns the TabBoxClient at given model index. If
      * the index is invalid, does not point to a Client or the list
      * is empty, NULL will be returned.
-     **/
+     */
     TabBoxClient* client(const QModelIndex& index) const;
     /**
      * @return The first model index. That is the model index at position 0, 0.
      * It is valid, as desktop has at least one desktop and if there are no
      * clients an empty item is created.
-     **/
+     */
     QModelIndex first() const;
 
     bool eventFilter(QObject *watcher, QEvent *event) override;
@@ -339,14 +336,14 @@ public:
     /**
      * @returns whether the TabBox operates in a no modifier grab mode.
      * In this mode a click on an item should directly accept and close the tabbox.
-     **/
+     */
     virtual bool noModifierGrab() const = 0;
 
 Q_SIGNALS:
     /**
      * This signal is fired when the TabBoxConfig changes
      * @see setConfig
-     **/
+     */
     void configChanged();
     void selectedIndexChanged();
 
@@ -364,7 +361,7 @@ private:
  *
  * @author Martin Gräßlin <mgraesslin@kde.org>
  * @since 4.4
- **/
+ */
 class TabBoxClient
 {
 public:
@@ -373,20 +370,20 @@ public:
 
     /**
      * @return The caption of the client
-     **/
+     */
     virtual QString caption() const = 0;
     /**
      * @param size Requested size of the icon
      * @return The icon of the client
-     **/
+     */
     virtual QIcon icon() const = 0;
     /**
      * @return The window Id of the client
-     **/
+     */
     virtual WId window() const = 0;
     /**
      * @return Minimized state of the client
-     **/
+     */
     virtual bool isMinimized() const = 0;
     virtual int x() const = 0;
     virtual int y() const = 0;
@@ -400,7 +397,7 @@ public:
 
 /**
  * Pointer to the global TabBoxHandler object.
- **/
+ */
 extern TabBoxHandler* tabBox;
 
 } // namespace TabBox
