@@ -37,7 +37,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QScopedPointer>
 #include <QProcess>
 // system
-#include <limits.h>
+#include <climits>
 Q_DECLARE_LOGGING_CATEGORY(KWIN_CORE)
 Q_DECLARE_LOGGING_CATEGORY(KWIN_VIRTUALKEYBOARD)
 namespace KWin
@@ -90,12 +90,6 @@ enum Layer {
     NumLayers // number of layers, must be last
 };
 
-// yes, I know this is not 100% like standard operator++
-inline void operator++(Layer& lay)
-{
-    lay = static_cast< Layer >(lay + 1);
-}
-
 enum StrutArea {
     StrutAreaInvalid = 0, // Null
     StrutAreaTop     = 1 << 0,
@@ -111,9 +105,10 @@ class StrutRect : public QRect
 public:
     explicit StrutRect(QRect rect = QRect(), StrutArea area = StrutAreaInvalid);
     StrutRect(const StrutRect& other);
+    StrutRect &operator=(const StrutRect& other);
     inline StrutArea area() const {
         return m_area;
-    };
+    }
 private:
     StrutArea m_area;
 };
@@ -131,7 +126,7 @@ enum ShadeMode {
  * Maximize mode. These values specify how a window is maximized.
  *
  * @note these values are written to session files, don't change the order
- **/
+ */
 enum MaximizeMode {
     MaximizeRestore    = 0, ///< The window is not maximized in any direction.
     MaximizeVertical   = 1, ///< The window is maximized vertically.
@@ -172,7 +167,7 @@ void KWIN_EXPORT ungrabXKeyboard();
  * ungrab are matched.
  *
  * To simplify usage consider using the macro GRAB_SERVER_DURING_CONTEXT
- **/
+ */
 class XServerGrabber
 {
 public:
@@ -199,7 +194,7 @@ Qt::KeyboardModifiers KWIN_EXPORT x11ToQtKeyboardModifiers(int state);
 
 /**
  * Separate the concept of an unet QPoint and 0,0
- **/
+ */
 class ClearablePoint
 {
 public:
@@ -226,13 +221,13 @@ private:
 
 /**
  * QProcess subclass which unblocks SIGUSR in the child process.
- **/
+ */
 class KWIN_EXPORT Process : public QProcess
 {
     Q_OBJECT
 public:
     explicit Process(QObject *parent = nullptr);
-    virtual ~Process();
+    ~Process() override;
 
 protected:
     void setupChildProcess() override;
